# textbag
textbag is a work-in-progress python module for implementing a bag-of-words transformation on various types of text data.

## Features
* Function to clean text (remove stop-words and punctuation).
* Function to create a set containing all words contained in whatever text data is passed.
* Function to create a bag of words representation of text data.

## Installation
pip3 install textbag

## Authors
* Jacob Der
